#
# spec file for package orthanc-gdcm
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-gdcm
Summary:        GDCM plugin for Orthanc
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
Version:        1.6
Release:        2.5
URL:            http://orthanc-server.com
Source0:        https://orthanc.uclouvain.be/downloads/sources/orthanc-gdcm/OrthancGdcm-%{version}.tar.gz
Source11:       orthanc-gdcm-readme.SUSE

BuildRequires:  cmake
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
BuildRequires:  gcc13-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  gdcm-devel >= 3.0.18
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_iostreams-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
#Workaround for boo#1180359
BuildRequires:  libbz2-devel
BuildRequires:  libuuid-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  unzip
#Workaround for boo#1180359
BuildRequires:  zlib-devel

Requires:       orthanc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
GDCM for Orthanc

%prep
%autosetup -n OrthancGdcm-%{version}

%build
%if 0%{?suse_version} == 1500 && 0%{?sle_version} > 150200
export CC=gcc-13
export CXX=g++-13
%endif
%cmake .. \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=OFF \
       -DSTANDALONE_BUILD=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/OrthancFramework/Sources \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install
%cmake_install

# architecture dependet files should not be in /usr/share...
# create a directory
mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins
mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#Link from lib64 to orthanc plugin-directory, where it is expected
ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancGdcm.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancGdcm.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/*.so

cp %{S:11} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Wed Mar 13 2024 Axel Braun <axel.braun@gmx.de>
- enable gcc13 for Leap 15
* Tue Jan 30 2024 Axel Braun <axel.braun@gmx.de>
- update to version 1.6
  Upgrade to GDCM 3.0.22 for static builds
* Fri Sep 23 2022 Axel Braun <axel.braun@gmx.de>
- changed dependency gdcm-libgdcm3_0 -> libgdcm3_0
* Fri Mar 25 2022 Axel Braun <axel.braun@gmx.de>
- Version 1.5
  * Take the configuration option "RestrictTransferSyntaxes" into
  account not only for decoding, but also for transcoding
  * Upgrade to GDCM 3.0.10 for static builds-
* Thu Jul 22 2021 Axel Braun <axel.braun@gmx.de>
- version 1.4
  * Prevent transcoding of 1bpp DICOM images, as this might crash GDCM
* Sat Jun 19 2021 Axel Braun <axel.braun@gmx.de>
- version 1.3
  * Prevent changing SOP class UID from "MR Image Storage" to "Enhanced
  MR Image Storage" during the transcoding
* Wed Dec 30 2020 Axel Braun <axel.braun@gmx.de>
- Workaround for boo#1180359
* Mon Dec 21 2020 Axel Braun <axel.braun@gmx.de>
- Version 1.2
  * Temporarily prevent transcoding of 16bpp images to JPEG, as this might crash GDCM
  * Upgrade to GDCM 3.0.8 for static builds
  * patches_logging.patch removed (included in source)
* Thu Dec 10 2020 Axel Braun <axel.braun@gmx.de>
- patches_logging.patch added to fix build error w. orthanc 1.8.1
* Sat Oct 17 2020 Axel Braun <axel.braun@gmx.de>
- version 1.1
  * Fix transcoding of DICOM files encoded using an implicit transfer syntax
  * Support of dynamic linking against the system-wide Orthanc framework
    library
  * Upgrade to GDCM 3.0.7 for static builds
* Tue May 26 2020 Axel Braun <axel.braun@gmx.de>
- version 1.0 of the plugin
  iniital build on OBS
